@@ -1,5 +1,43 @@
 var NAVTREEINDEX73 =
 {
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlField2.html#acbbc03b5ffb494e1045836ad21e0a34c":[3,0,0,0,0,41,20,0],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMember.html":[2,0,0,0,0,42,21],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMember.html":[3,0,0,0,0,41,21],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMember.html#a11335e13e50af74108bf926dc1340b4b":[2,0,0,0,0,42,21,1],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMember.html#a11335e13e50af74108bf926dc1340b4b":[3,0,0,0,0,41,21,1],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMember.html#a437dd590d809a92e93d0c0c78804998f":[2,0,0,0,0,42,21,0],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMember.html#a437dd590d809a92e93d0c0c78804998f":[3,0,0,0,0,41,21,0],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMethod.html":[2,0,0,0,0,42,22],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMethod.html":[3,0,0,0,0,41,22],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMethod.html#a4625eba7150dcadd5bb85a0369cf33ff":[2,0,0,0,0,42,22,5],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMethod.html#a4625eba7150dcadd5bb85a0369cf33ff":[3,0,0,0,0,41,22,5],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMethod.html#a5965a42d85686ee3c597be7ffb9ff5c1":[2,0,0,0,0,42,22,3],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMethod.html#a5965a42d85686ee3c597be7ffb9ff5c1":[3,0,0,0,0,41,22,3],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMethod.html#a893d9c8b06f0556a8426b49abb010c98":[2,0,0,0,0,42,22,1],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMethod.html#a893d9c8b06f0556a8426b49abb010c98":[3,0,0,0,0,41,22,1],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMethod.html#aab9b0b042366fbe1e3d585f2f1b4799a":[2,0,0,0,0,42,22,4],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMethod.html#aab9b0b042366fbe1e3d585f2f1b4799a":[3,0,0,0,0,41,22,4],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMethod.html#aaf0692b3fe846cc7b0523585c83cb1ca":[2,0,0,0,0,42,22,2],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMethod.html#aaf0692b3fe846cc7b0523585c83cb1ca":[3,0,0,0,0,41,22,2],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMethod.html#ae878ee8caba4a72ced8324c8443e2c66":[2,0,0,0,0,42,22,0],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMethod.html#ae878ee8caba4a72ced8324c8443e2c66":[3,0,0,0,0,41,22,0],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlReflection.html":[2,0,0,0,0,42,23],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlReflection.html":[3,0,0,0,0,41,23],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlReflection.html#ac02f20fba3b32b5b3f1f3d6d517a4f8e":[2,0,0,0,0,42,23,1],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlReflection.html#ac02f20fba3b32b5b3f1f3d6d517a4f8e":[3,0,0,0,0,41,23,1],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlReflection.html#af736b2d39f3cd68351caeffc2a1a6047":[2,0,0,0,0,42,23,0],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlReflection.html#af736b2d39f3cd68351caeffc2a1a6047":[3,0,0,0,0,41,23,0],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIndirectTypeDescription.html":[2,0,0,0,0,42,24],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIndirectTypeDescription.html":[3,0,0,0,0,41,24],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIndirectTypeDescription.html#aaad9bc2d48229d099d8b6869b2001abb":[2,0,0,0,0,42,24,0],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XIndirectTypeDescription.html#aaad9bc2d48229d099d8b6869b2001abb":[3,0,0,0,0,41,24,0],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XInterfaceAttributeTypeDescription.html":[2,0,0,0,0,42,25],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XInterfaceAttributeTypeDescription.html":[3,0,0,0,0,41,25],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XInterfaceAttributeTypeDescription.html#a0b222b18821cdbf0634a3687c9619c8a":[2,0,0,0,0,42,25,0],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XInterfaceAttributeTypeDescription.html#a0b222b18821cdbf0634a3687c9619c8a":[3,0,0,0,0,41,25,0],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XInterfaceAttributeTypeDescription.html#ad12f8f171276bdb3906ea2854726367c":[2,0,0,0,0,42,25,1],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XInterfaceAttributeTypeDescription.html#ad12f8f171276bdb3906ea2854726367c":[3,0,0,0,0,41,25,1],
+"interfacecom_1_1sun_1_1star_1_1reflection_1_1XInterfaceAttributeTypeDescription2.html":[2,0,0,0,0,42,26],
 "interfacecom_1_1sun_1_1star_1_1reflection_1_1XInterfaceAttributeTypeDescription2.html":[3,0,0,0,0,41,26],
 "interfacecom_1_1sun_1_1star_1_1reflection_1_1XInterfaceAttributeTypeDescription2.html#a70aeff2c54416df0879c7bbcfd086f7c":[2,0,0,0,0,42,26,2],
 "interfacecom_1_1sun_1_1star_1_1reflection_1_1XInterfaceAttributeTypeDescription2.html#a70aeff2c54416df0879c7bbcfd086f7c":[3,0,0,0,0,41,26,2],
@@ -211,43 +249,5 @@ var NAVTREEINDEX73 =
 "interfacecom_1_1sun_1_1star_1_1registry_1_1XRegistryKey.html#ace82cb2db5387d3c9a35ac9b2fe7ae76":[3,0,0,0,0,42,10,20],
 "interfacecom_1_1sun_1_1star_1_1registry_1_1XRegistryKey.html#ad12f8f171276bdb3906ea2854726367c":[2,0,0,0,0,43,10,17],
 "interfacecom_1_1sun_1_1star_1_1registry_1_1XRegistryKey.html#ad12f8f171276bdb3906ea2854726367c":[3,0,0,0,0,42,10,17],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XRegistryKey.html#ad3639728fe69b6346c9e5f77b6b30818":[2,0,0,0,0,43,10,19],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XRegistryKey.html#ad3639728fe69b6346c9e5f77b6b30818":[3,0,0,0,0,42,10,19],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XRegistryKey.html#ad75286a69f558484322dac5297e2ed64":[2,0,0,0,0,43,10,28],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XRegistryKey.html#ad75286a69f558484322dac5297e2ed64":[3,0,0,0,0,42,10,28],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XRegistryKey.html#af9c415f2f53db0c3438f99579b5016db":[2,0,0,0,0,43,10,4],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XRegistryKey.html#af9c415f2f53db0c3438f99579b5016db":[3,0,0,0,0,42,10,4],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XRegistryKey.html#afb80fa7627d5a63cdfc5a7eda9c52cb9":[2,0,0,0,0,43,10,11],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XRegistryKey.html#afb80fa7627d5a63cdfc5a7eda9c52cb9":[3,0,0,0,0,42,10,11],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html":[2,0,0,0,0,43,11],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html":[3,0,0,0,0,42,11],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#a06d11978c9a9cb071b292067e02d510c":[2,0,0,0,0,43,11,7],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#a06d11978c9a9cb071b292067e02d510c":[3,0,0,0,0,42,11,7],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#a3a80b6032f86a56bec74609034b3246f":[2,0,0,0,0,43,11,1],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#a3a80b6032f86a56bec74609034b3246f":[3,0,0,0,0,42,11,1],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#a487d5f454cff4db530ed7b5b690ec71d":[2,0,0,0,0,43,11,5],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#a487d5f454cff4db530ed7b5b690ec71d":[3,0,0,0,0,42,11,5],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#a5ae591df94fc66ccb85cbb6565368bca":[2,0,0,0,0,43,11,0],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#a5ae591df94fc66ccb85cbb6565368bca":[3,0,0,0,0,42,11,0],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#a6e40da26806154c0dbeeaf1841c56ea4":[2,0,0,0,0,43,11,2],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#a6e40da26806154c0dbeeaf1841c56ea4":[3,0,0,0,0,42,11,2],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#ac023f5d4fe2ae6f56a7eebee05da2a09":[2,0,0,0,0,43,11,6],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#ac023f5d4fe2ae6f56a7eebee05da2a09":[3,0,0,0,0,42,11,6],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#ad12f8f171276bdb3906ea2854726367c":[2,0,0,0,0,43,11,4],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#ad12f8f171276bdb3906ea2854726367c":[3,0,0,0,0,42,11,4],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#ae3c4fecf585029fd3c5432e277465346":[2,0,0,0,0,43,11,3],
-"interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#ae3c4fecf585029fd3c5432e277465346":[3,0,0,0,0,42,11,3],
-"interfacecom_1_1sun_1_1star_1_1rendering_1_1XAnimatedSprite.html":[2,0,0,0,0,44,46],
-"interfacecom_1_1sun_1_1star_1_1rendering_1_1XAnimatedSprite.html":[3,0,0,0,0,43,22],
-"interfacecom_1_1sun_1_1star_1_1rendering_1_1XAnimatedSprite.html#a0f9724bdafc120773f3700d429c48fa3":[2,0,0,0,0,44,46,2],
-"interfacecom_1_1sun_1_1star_1_1rendering_1_1XAnimatedSprite.html#a0f9724bdafc120773f3700d429c48fa3":[3,0,0,0,0,43,22,2],
-"interfacecom_1_1sun_1_1star_1_1rendering_1_1XAnimatedSprite.html#a5a2945c2d245090441e4342070a1d187":[2,0,0,0,0,44,46,1],
-"interfacecom_1_1sun_1_1star_1_1rendering_1_1XAnimatedSprite.html#a5a2945c2d245090441e4342070a1d187":[3,0,0,0,0,43,22,1],
-"interfacecom_1_1sun_1_1star_1_1rendering_1_1XAnimatedSprite.html#a5c924d660acf485fba55498594b93a74":[2,0,0,0,0,44,46,5],
-"interfacecom_1_1sun_1_1star_1_1rendering_1_1XAnimatedSprite.html#a5c924d660acf485fba55498594b93a74":[3,0,0,0,0,43,22,5],
-"interfacecom_1_1sun_1_1star_1_1rendering_1_1XAnimatedSprite.html#a84c1367b486680bcf22987540e217cfb":[2,0,0,0,0,44,46,4],
-"interfacecom_1_1sun_1_1star_1_1rendering_1_1XAnimatedSprite.html#a84c1367b486680bcf22987540e217cfb":[3,0,0,0,0,43,22,4],
-"interfacecom_1_1sun_1_1star_1_1rendering_1_1XAnimatedSprite.html#a96ff5acd907b00d811b18b728c983889":[2,0,0,0,0,44,46,3],
-"interfacecom_1_1sun_1_1star_1_1rendering_1_1XAnimatedSprite.html#a96ff5acd907b00d811b18b728c983889":[3,0,0,0,0,43,22,3],
-"interfacecom_1_1sun_1_1star_1_1rendering_1_1XAnimatedSprite.html#aa610bd85ee9f30b9537a6e9950871cc2":[2,0,0,0,0,44,46,0]
+"interfacecom_1_1sun_1_1star_1_1registry_1_1XRegistryKey.html#ad3639728fe69b6346c9e5f77b6b30818":[2,0,0,0,0,43,10,19]
 };
