@@ -39,7 +39,7 @@ var searchData=
   ['destroyelement_36',['destroyElement',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XLayoutManager.html#a0b443e2c14b98bdd4392593094845fd7',1,'com::sun::star::frame::XLayoutManager']]],
   ['destroygraph_37',['destroyGraph',['../interfacecom_1_1sun_1_1star_1_1rdf_1_1XRepository.html#a5cac8eee77b972e38e42896253a68e8f',1,'com::sun::star::rdf::XRepository']]],
   ['detach_38',['detach',['../interfacecom_1_1sun_1_1star_1_1script_1_1XEventAttacherManager.html#a3fe259f5a6328e0924178db9d78289ca',1,'com::sun::star::script::XEventAttacherManager']]],
-  ['detect_39',['detect',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XExtendedFilterDetection.html#ac575499aa1fb6c8eb25f4b7ee646e85e',1,'com::sun::star::frame::XExtendedFilterDetection::detect()'],['../interfacecom_1_1sun_1_1star_1_1document_1_1XExtendedFilterDetection.html#a83f8a8ae5fc3ea370002c78e7164569c',1,'com::sun::star::document::XExtendedFilterDetection::detect()']]],
+  ['detect_39',['detect',['../interfacecom_1_1sun_1_1star_1_1document_1_1XExtendedFilterDetection.html#a83f8a8ae5fc3ea370002c78e7164569c',1,'com::sun::star::document::XExtendedFilterDetection::detect()'],['../interfacecom_1_1sun_1_1star_1_1frame_1_1XExtendedFilterDetection.html#ac575499aa1fb6c8eb25f4b7ee646e85e',1,'com::sun::star::frame::XExtendedFilterDetection::detect()']]],
   ['detectarguments_40',['detectArguments',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1data_1_1XDataProvider.html#a5f4349946818f3e5856ba62e9636a631',1,'com::sun::star::chart2::data::XDataProvider']]],
   ['detectnumberformat_41',['detectNumberFormat',['../interfacecom_1_1sun_1_1star_1_1util_1_1XNumberFormatter.html#a108d65c193eeb89feb9ba9c7152d62b0',1,'com::sun::star::util::XNumberFormatter']]],
   ['dialogclosed_42',['dialogClosed',['../interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XDialogClosedListener.html#af09e15128ac384291d08ca9d3e59e0cf',1,'com::sun::star::ui::dialogs::XDialogClosedListener']]],
@@ -93,13 +93,13 @@ var searchData=
   ['doscaling_90',['doScaling',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1XScaling.html#a674daff794ca084bf1229963e23bc865',1,'com::sun::star::chart2::XScaling']]],
   ['doubleclick_91',['doubleClick',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XStatusbarController.html#a9ab62e3d98e96846e553805206a4510f',1,'com::sun::star::frame::XStatusbarController::doubleClick()'],['../interfacecom_1_1sun_1_1star_1_1frame_1_1XToolbarController.html#a029af899a4779fe3577bcdbb68c2946c',1,'com::sun::star::frame::XToolbarController::doubleClick()']]],
   ['doverb_92',['doVerb',['../interfacecom_1_1sun_1_1star_1_1embed_1_1XEmbeddedObject.html#af02a6df42b7bcc536d8cd1c52b4e86dc',1,'com::sun::star::embed::XEmbeddedObject']]],
-  ['down_93',['down',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XSpinListener.html#aadc9384d0b0582584dc587c3e4068a51',1,'com::sun::star::awt::XSpinListener::down()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XSpinField.html#a6663cf1e20c2f8162d29d31c8f6324e6',1,'com::sun::star::awt::XSpinField::down()']]],
+  ['down_93',['down',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XSpinField.html#a6663cf1e20c2f8162d29d31c8f6324e6',1,'com::sun::star::awt::XSpinField::down()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XSpinListener.html#aadc9384d0b0582584dc587c3e4068a51',1,'com::sun::star::awt::XSpinListener::down()']]],
   ['dragdropend_94',['dragDropEnd',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDragSourceListener.html#a53d5bd969e7911686436ad6d0615caf5',1,'com::sun::star::datatransfer::dnd::XDragSourceListener']]],
   ['dragenter_95',['dragEnter',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDragSourceListener.html#aeb1254a76ac041854da438cbb2d76e03',1,'com::sun::star::datatransfer::dnd::XDragSourceListener::dragEnter()'],['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDropTargetListener.html#a1f0800723ea156e271cdc17f28e84b56',1,'com::sun::star::datatransfer::dnd::XDropTargetListener::dragEnter()']]],
   ['dragexit_96',['dragExit',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDragSourceListener.html#a985b1df1ec59b6f07b85a3e7df95e7e5',1,'com::sun::star::datatransfer::dnd::XDragSourceListener::dragExit()'],['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDropTargetListener.html#a5bb38bbdf63cfdc866e1f08db1065189',1,'com::sun::star::datatransfer::dnd::XDropTargetListener::dragExit()']]],
   ['draggesturerecognized_97',['dragGestureRecognized',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDragGestureListener.html#a7a469b62d7cc8148a1bd032036c2eced',1,'com::sun::star::datatransfer::dnd::XDragGestureListener']]],
   ['dragover_98',['dragOver',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDragSourceListener.html#a727b75f0dab7ecc974476dcc66026f06',1,'com::sun::star::datatransfer::dnd::XDragSourceListener::dragOver()'],['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDropTargetListener.html#afa669a5669dbb67d5a548d9103fa0a2a',1,'com::sun::star::datatransfer::dnd::XDropTargetListener::dragOver()']]],
-  ['draw_99',['draw',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a4ea3de0291b97137621a9f9a815d0c2d',1,'com::sun::star::awt::XGraphics::draw()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XMtfRenderer.html#ac23bdb89ec917c28ac19f374abc21099',1,'com::sun::star::rendering::XMtfRenderer::draw()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XView.html#adce2d92a1139e5b7cb82981264070814',1,'com::sun::star::awt::XView::draw()']]],
+  ['draw_99',['draw',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a4ea3de0291b97137621a9f9a815d0c2d',1,'com::sun::star::awt::XGraphics::draw()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XView.html#adce2d92a1139e5b7cb82981264070814',1,'com::sun::star::awt::XView::draw()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XMtfRenderer.html#ac23bdb89ec917c28ac19f374abc21099',1,'com::sun::star::rendering::XMtfRenderer::draw()']]],
   ['drawarc_100',['drawArc',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a8554b44445ddb7337ea518872014e3a9',1,'com::sun::star::awt::XGraphics']]],
   ['drawbezier_101',['drawBezier',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XCanvas.html#af8c89b14291cedce5db368f6165ec92c',1,'com::sun::star::rendering::XCanvas']]],
   ['drawbitmap_102',['drawBitmap',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XCanvas.html#a015d88244db674156d2dd2d239a3e671',1,'com::sun::star::rendering::XCanvas::drawBitmap()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XSimpleCanvas.html#abe76e8727aee779e231ce30d29b60fb5',1,'com::sun::star::rendering::XSimpleCanvas::drawBitmap()']]],
@@ -117,7 +117,7 @@ var searchData=
   ['drawpolypolygon_114',['drawPolyPolygon',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a1cea898bba12b80148cd3d8483fd2463',1,'com::sun::star::awt::XGraphics::drawPolyPolygon()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XCanvas.html#a5b37e1456b7db1f9c3c8d2f31e1ca0e1',1,'com::sun::star::rendering::XCanvas::drawPolyPolygon()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XSimpleCanvas.html#a97e1c3812e715ed269a5d4e46bd04e72',1,'com::sun::star::rendering::XSimpleCanvas::drawPolyPolygon()']]],
   ['drawrect_115',['drawRect',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#ab18470b0d531232ef86df7e348bd51b9',1,'com::sun::star::awt::XGraphics::drawRect()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XSimpleCanvas.html#a7230c2d9337a27a4fd8e313768b44033',1,'com::sun::star::rendering::XSimpleCanvas::drawRect()']]],
   ['drawroundedrect_116',['drawRoundedRect',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#ac25f55e7df3ffff7ff8ca2d1b886dc2f',1,'com::sun::star::awt::XGraphics']]],
-  ['drawtext_117',['drawText',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XSimpleCanvas.html#ab9025cbb3845a4090b87b021b288ea08',1,'com::sun::star::rendering::XSimpleCanvas::drawText()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a3b5461dd56ead4d80e8aacf91bd6224f',1,'com::sun::star::awt::XGraphics::drawText()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XCanvas.html#a067eead9e2ebdfd2d8125b23e83e8fba',1,'com::sun::star::rendering::XCanvas::drawText()']]],
+  ['drawtext_117',['drawText',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a3b5461dd56ead4d80e8aacf91bd6224f',1,'com::sun::star::awt::XGraphics::drawText()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XCanvas.html#a067eead9e2ebdfd2d8125b23e83e8fba',1,'com::sun::star::rendering::XCanvas::drawText()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XSimpleCanvas.html#ab9025cbb3845a4090b87b021b288ea08',1,'com::sun::star::rendering::XSimpleCanvas::drawText()']]],
   ['drawtextarray_118',['drawTextArray',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XGraphics.html#a5823270f9a31c5d7258670ae721f8978',1,'com::sun::star::awt::XGraphics']]],
   ['drawtextlayout_119',['drawTextLayout',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XCanvas.html#a716e2ac0ee24cd191ec1a8ce7d02a97c',1,'com::sun::star::rendering::XCanvas']]],
   ['drop_120',['drop',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDropTargetListener.html#acd39324279313e59fabf50fdb811f0c7',1,'com::sun::star::datatransfer::dnd::XDropTargetListener']]],
