@@ -1,5 +1,5 @@
 var servicecom_1_1sun_1_1star_1_1chart_1_1Chart3DBarProperties =
 [
-    [ "XPropertySet", "servicecom_1_1sun_1_1star_1_1chart_1_1Chart3DBarProperties.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
+    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1chart_1_1Chart3DBarProperties.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
     [ "SolidType", "servicecom_1_1sun_1_1star_1_1chart_1_1Chart3DBarProperties.html#aaff67126f24e9dccbc1c538b16ac1c44", null ]
 ];
\ No newline at end of file
